@@ -17,15 +17,23 @@ use Carbon\Carbon;
 use Carbon\CarbonImmutable;
 use Carbon\CarbonInterface;
 use Carbon\CarbonInterval;
+use Carbon\CarbonPeriod;
+use Carbon\CarbonTimeZone;
 use Carbon\Translator;
 use Closure;
 use DateTime;
 use PHPUnit\Framework\TestCase;
 use ReflectionProperty;
+use Tests\PHPUnit\AssertObjectHasPropertyTrait;
 use Throwable;
 
+/**
+ * @SuppressWarnings(PHPMD.NumberOfChildren)
+ */
 abstract class AbstractTestCase extends TestCase
 {
+    use AssertObjectHasPropertyTrait;
+
     /**
      * @var \Carbon\Carbon
      */
@@ -51,6 +59,11 @@ abstract class AbstractTestCase extends TestCase
      */
     private $saveTz;
 
+    /**
+     * @var class-string<CarbonPeriod>
+     */
+    protected $periodClass = CarbonPeriod::class;
+
     protected function getTimestamp()
     {
         return (new DateTime())->getTimestamp();
@@ -169,6 +182,9 @@ abstract class AbstractTestCase extends TestCase
         $this->assertSame($expected, $actual);
     }
 
+    /**
+     * @phpstan-assert CarbonInterface $d
+     */
     public function assertInstanceOfCarbon($d)
     {
         $this->assertInstanceOf(CarbonInterface::class, $d);
@@ -217,6 +233,9 @@ abstract class AbstractTestCase extends TestCase
         }
     }
 
+    /**
+     * @phpstan-assert CarbonInterval $d
+     */
     public function assertInstanceOfCarbonInterval($d)
     {
         $this->assertInstanceOf(CarbonInterval::class, $d);
@@ -310,4 +329,19 @@ abstract class AbstractTestCase extends TestCase
 
         return $a === $b;
     }
+
+    protected function firstValidTimezoneAmong(array $timezones): CarbonTimeZone
+    {
+        $firstError = null;
+
+        foreach ($timezones as $timezone) {
+            try {
+                return new CarbonTimeZone($timezone);
+            } catch (Throwable $exception) {
+                $firstError = $firstError ?? $exception;
+            }
+        }
+
+        throw $firstError;
+    }
 }
