@@ -26,7 +26,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testKeyAndCurrentAreCorrectlyInstantiated()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $this->assertSame(0, $period->key());
         $this->assertInstanceOfCarbon($period->current());
@@ -36,14 +36,14 @@ class IteratorTest extends AbstractTestCase
 
     public function testValidIsCorrectlyInstantiated()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $this->assertTrue($period->valid());
     }
 
     public function testCurrentIsAlwaysCarbonInstance()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         foreach ($period as $key => $current) {
             $this->assertInstanceOfCarbon($current);
@@ -56,7 +56,7 @@ class IteratorTest extends AbstractTestCase
     {
         $keys = [];
 
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         foreach ($period as $key => $current) {
             $this->assertIsInt($keys[] = $key);
@@ -68,7 +68,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testElementsInLoopAreAlwaysValid()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         foreach ($period as $key => $current) {
             $this->assertTrue($period->valid());
@@ -77,7 +77,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testKeyAndCurrentAreCorrectlyIterated()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $period->next();
 
@@ -88,7 +88,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testKeyAndCurrentAreCorrectlyRewound()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $period->next();
         $period->rewind();
@@ -100,7 +100,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testKeyAndCurrentAreNullAfterIteration()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         foreach ($period as $key => $current) {
             //
@@ -112,16 +112,17 @@ class IteratorTest extends AbstractTestCase
     }
 
     /**
-     * @dataProvider \Tests\CarbonPeriod\IteratorTest::dataForIterateBackwardsArguments
+     * @dataProvider dataForIterateBackwardsArguments
      */
     public function testIterateBackwards($arguments, $expected)
     {
-        $period = CarbonPeriod::create(...$arguments);
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create(...$arguments);
 
         $interval = new CarbonInterval('P3D');
         $interval->invert = 1;
 
-        $period->setDateInterval($interval);
+        $period = $period->setDateInterval($interval);
 
         $this->assertSame(
             $this->standardizeDates($expected),
@@ -155,12 +156,13 @@ class IteratorTest extends AbstractTestCase
 
     public function testChangingParametersShouldNotCauseInfiniteLoop()
     {
-        $period = CarbonPeriod::create()
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create()
             ->setStartDate($start = '2012-07-01')
             ->setEndDate($end = '2012-07-20')
             ->setDateInterval($interval = 'P1D')
             ->setRecurrences($recurrences = 10)
-            ->setOptions($options = CarbonPeriod::EXCLUDE_START_DATE | CarbonPeriod::EXCLUDE_END_DATE)
+            ->setOptions($options = $periodClass::EXCLUDE_START_DATE | $periodClass::EXCLUDE_END_DATE)
             ->addFilter($filter = function () {
                 return true;
             });
@@ -190,7 +192,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testChangeEndDateDuringIteration()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $results = [];
 
@@ -198,7 +200,7 @@ class IteratorTest extends AbstractTestCase
             $results[] = sprintf('%s => %s', $key, $current->toDateString());
 
             if ($current->toDateString() === '2012-07-16') {
-                $period->setEndDate($current);
+                $period = $period->setEndDate($current);
 
                 // Note: Current is no longer valid, because it is now equal to end, which is excluded.
                 $this->assertNull($period->key());
@@ -307,7 +309,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testValidateOncePerIteration()
     {
-        $period = CarbonPeriodFactory::withCounter($counter);
+        $period = CarbonPeriodFactory::withCounter($this->periodClass, $counter);
 
         $period->key();
         $period->current();
@@ -325,18 +327,19 @@ class IteratorTest extends AbstractTestCase
 
     public function testInvalidateCurrentAfterChangingParameters()
     {
-        $period = CarbonPeriod::create('2012-10-01');
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create('2012-10-01');
 
         $this->assertInstanceOfCarbon($period->current());
 
-        $period->addFilter(CarbonPeriod::END_ITERATION);
+        $period = $period->addFilter($periodClass::END_ITERATION);
 
         $this->assertNull($period->current());
     }
 
     public function testTraversePeriodDynamically()
     {
-        $period = CarbonPeriodFactory::withEvenDaysFilter();
+        $period = CarbonPeriodFactory::withEvenDaysFilter($this->periodClass);
 
         $results = [];
 
@@ -358,7 +361,8 @@ class IteratorTest extends AbstractTestCase
 
     public function testExtendCompletedIteration()
     {
-        $period = CarbonPeriod::create('2018-10-10', '2018-10-11');
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create('2018-10-10', '2018-10-11');
 
         $results = [];
 
@@ -368,7 +372,7 @@ class IteratorTest extends AbstractTestCase
             $period->next();
         }
 
-        $period->setEndDate('2018-10-13');
+        $period = $period->setEndDate('2018-10-13');
 
         while ($period->valid()) {
             $results[] = $period->current();
@@ -384,51 +388,54 @@ class IteratorTest extends AbstractTestCase
 
     public function testRevalidateCurrentAfterChangeOfParameters()
     {
-        $period = CarbonPeriod::create()->setStartDate($start = new Carbon('2018-10-28'));
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create()->setStartDate($start = new Carbon('2018-10-28'));
         $this->assertEquals($start, $period->current());
         $this->assertNotSame($start, $period->current());
 
-        $period->addFilter($excludeStart = function ($date) use ($start) {
+        $period = $period->addFilter($excludeStart = function ($date) use ($start) {
             return $date != $start;
         });
         $this->assertNull($period->current());
 
-        $period->removeFilter($excludeStart);
+        $period = $period->removeFilter($excludeStart);
         $this->assertEquals($start, $period->current());
         $this->assertNotSame($start, $period->current());
     }
 
     public function testRevalidateCurrentAfterEndOfIteration()
     {
-        $period = CarbonPeriod::create()->setStartDate($start = new Carbon('2018-10-28'));
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create()->setStartDate($start = new Carbon('2018-10-28'));
         $this->assertEquals($start, $period->current());
         $this->assertNotSame($start, $period->current());
 
-        $period->addFilter(CarbonPeriod::END_ITERATION);
+        $period = $period->addFilter($periodClass::END_ITERATION);
         $this->assertNull($period->current());
 
-        $period->removeFilter(CarbonPeriod::END_ITERATION);
+        $period = $period->removeFilter($periodClass::END_ITERATION);
         $this->assertEquals($start, $period->current());
         $this->assertNotSame($start, $period->current());
     }
 
     public function testChangeStartDateBeforeIteration()
     {
-        $period = CarbonPeriod::create(new Carbon('2018-10-05'), 3);
-
-        $period->setStartDate(new Carbon('2018-10-13'));
-        $period->toggleOptions(CarbonPeriod::EXCLUDE_START_DATE, true);
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create(new Carbon('2018-10-05'), 3)
+            ->setStartDate(new Carbon('2018-10-13'))
+            ->toggleOptions($periodClass::EXCLUDE_START_DATE, true);
 
         $this->assertEquals(new Carbon('2018-10-14'), $period->current());
     }
 
     public function testChangeStartDateAfterStartedIteration()
     {
-        $period = CarbonPeriod::create(new Carbon('2018-10-05'), 3);
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create(new Carbon('2018-10-05'), 3);
 
         $current = $period->current();
 
-        $period->toggleOptions(CarbonPeriod::EXCLUDE_START_DATE, true);
+        $period->toggleOptions($periodClass::EXCLUDE_START_DATE, true);
         $period->setStartDate(new Carbon('2018-10-13'));
 
         $this->assertEquals($current, $period->current());
@@ -436,7 +443,8 @@ class IteratorTest extends AbstractTestCase
 
     public function testInvertDateIntervalDuringIteration()
     {
-        $period = new CarbonPeriod('2018-04-11', 5);
+        $periodClass = $this->periodClass;
+        $period = new $periodClass('2018-04-11', 5);
 
         $results = [];
 
@@ -456,7 +464,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testManualIteration()
     {
-        $period = CarbonPeriodFactory::withStackFilter();
+        $period = CarbonPeriodFactory::withStackFilter($this->periodClass);
         $period->rewind();
         $str = '';
         while ($period->valid()) {
@@ -472,7 +480,8 @@ class IteratorTest extends AbstractTestCase
 
     public function testSkip()
     {
-        $period = CarbonPeriod::create('2018-05-30', '2018-07-13');
+        $periodClass = $this->periodClass;
+        $period = $periodClass::create('2018-05-30', '2018-07-13');
         $output = [];
 
         foreach ($period as $day) {
@@ -522,7 +531,7 @@ class IteratorTest extends AbstractTestCase
     public function testLocale()
     {
         /** @var CarbonPeriod $period */
-        $period = CarbonPeriodFactory::withStackFilter()->locale('de');
+        $period = CarbonPeriodFactory::withStackFilter($this->periodClass)->locale('de');
         $str = '';
 
         foreach ($period as $key => $date) {
@@ -538,7 +547,7 @@ class IteratorTest extends AbstractTestCase
 
     public function testTimezone()
     {
-        $period = CarbonPeriodFactory::withStackFilter()->shiftTimezone('America/Toronto');
+        $period = CarbonPeriodFactory::withStackFilter($this->periodClass)->shiftTimezone('America/Toronto');
         $str = null;
 
         foreach ($period as $key => $date) {
