@@ -1,6 +1,16 @@
 <?php
+
 declare(strict_types=1);
 
+/**
+ * This file is part of the Carbon package.
+ *
+ * (c) Brian Nesbitt <brian@nesbot.com>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
 namespace Tests\Laravel;
 
 class EventDispatcherBase
@@ -23,7 +33,7 @@ class EventDispatcherBase
     {
         if (isset($this->listeners[$name])) {
             foreach ($this->listeners[$name] as $listener) {
-                call_user_func($listener, $event);
+                $listener($event);
             }
         }
     }
